@@ -1287,7 +1287,7 @@ typedef union YYSTYPE
 {
 
 /* Line 1676 of yacc.c  */
-#line 972 "/export/home/pb2/build/sb_0-12329462-1401959639.81/mysql-5.6.19-apt-repo-export-6701309_gpl/sql/sql_yacc.yy"
+#line 967 "/export/home/pb2/build/sb_0-14135359-1421674846.01/mysql-5.6.23-release-export-7480611_gpl/sql/sql_yacc.yy"
 
   int  num;
   ulong ulong_num;
@@ -1348,7 +1348,7 @@ typedef union YYSTYPE
 
 
 /* Line 1676 of yacc.c  */
-#line 1352 "/export/home/pb2/build/sb_0-12329462-1401959639.81/dist_GPL/sql/sql_yacc.h"
+#line 1352 "/export/home/pb2/build/sb_0-14135359-1421674846.01/dist_GPL/sql/sql_yacc.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
